==> openshift-model-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/ProjectListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ProjectListFluent<A extends ProjectListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Project item);
    public A setToItems(int index,Project item);
    public A addToItems(Project... items);
    public A addAllToItems(Collection<Project> items);
    public A removeFromItems(Project... items);
    public A removeAllFromItems(Collection<Project> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ProjectBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Project> getItems();
    public List<Project> buildItems();
    public Project buildItem(int index);
    public Project buildFirstItem();
    public Project buildLastItem();
    public Project buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ProjectBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ProjectBuilder> predicate);
    public A withItems(List<Project> items);
    public A withItems(Project... items);
    public Boolean hasItems();
    public ProjectListFluent.ItemsNested<A> addNewItem();
    public ProjectListFluent.ItemsNested<A> addNewItemLike(Project item);
    public ProjectListFluent.ItemsNested<A> setNewItemLike(int index,Project item);
    public ProjectListFluent.ItemsNested<A> editItem(int index);
    public ProjectListFluent.ItemsNested<A> editFirstItem();
    public ProjectListFluent.ItemsNested<A> editLastItem();
    public ProjectListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ProjectBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProjectFluent<ProjectListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/ProjectListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ProjectListFluent<A extends ProjectListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Project item);
    public A setToItems(int index,Project item);
    public A addToItems(Project... items);
    public A addAllToItems(Collection<Project> items);
    public A removeFromItems(Project... items);
    public A removeAllFromItems(Collection<Project> items);
    public A removeMatchingFromItems(Predicate<ProjectBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Project> getItems();
    public List<Project> buildItems();
    public Project buildItem(int index);
    public Project buildFirstItem();
    public Project buildLastItem();
    public Project buildMatchingItem(Predicate<ProjectBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ProjectBuilder> predicate);
    public A withItems(List<Project> items);
    public A withItems(Project... items);
    public Boolean hasItems();
    public ProjectListFluent.ItemsNested<A> addNewItem();
    public ProjectListFluent.ItemsNested<A> addNewItemLike(Project item);
    public ProjectListFluent.ItemsNested<A> setNewItemLike(int index,Project item);
    public ProjectListFluent.ItemsNested<A> editItem(int index);
    public ProjectListFluent.ItemsNested<A> editFirstItem();
    public ProjectListFluent.ItemsNested<A> editLastItem();
    public ProjectListFluent.ItemsNested<A> editMatchingItem(Predicate<ProjectBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProjectFluent<ProjectListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
